# scooterbot_agent
Scooterbot Agent


## Versions

### 2.0.0

- openai-agents
- async replies

### 1.0.5

- relax tenacity dependency

### 1.0.4

- add tenacity dependency since it's not in python 3.9 stdlib

### 1.0.3

- relax python compat to 3.9

### 1.0.1

- fix bad pypi deploy

### 1.0.0

- initial version

